==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerSpecTemplateFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerSpecTemplateFluentImpl<A extends TriggerSpecTemplateFluent<A>> extends BaseFluent<A> implements TriggerSpecTemplateFluent<A>{
  public TriggerSpecTemplateFluentImpl() {
  }
  public TriggerSpecTemplateFluentImpl(TriggerSpecTemplate instance) {
    this.withApiversion(instance.getApiversion()); 
    this.withRef(instance.getRef()); 
    this.withSpec(instance.getSpec()); 
  }
  private String apiversion;
  private String ref;
  private TriggerTemplateSpecBuilder spec;
  public String getApiversion() {
    return this.apiversion;
  }
  public A withApiversion(String apiversion) {
    this.apiversion=apiversion; return (A) this;
  }
  public Boolean hasApiversion() {
    return this.apiversion != null;
  }
  public String getRef() {
    return this.ref;
  }
  public A withRef(String ref) {
    this.ref=ref; return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerTemplateSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerTemplateSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerTemplateSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerTemplateSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerSpecTemplateFluent.SpecNested<A> withNewSpec() {
    return new TriggerSpecTemplateFluentImpl.SpecNestedImpl();
  }
  public TriggerSpecTemplateFluent.SpecNested<A> withNewSpecLike(TriggerTemplateSpec item) {
    return new TriggerSpecTemplateFluentImpl.SpecNestedImpl(item);
  }
  public TriggerSpecTemplateFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerSpecTemplateFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerTemplateSpecBuilder().build());
  }
  public TriggerSpecTemplateFluent.SpecNested<A> editOrNewSpecLike(TriggerTemplateSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TriggerSpecTemplateFluentImpl that = (TriggerSpecTemplateFluentImpl) o;
    if (apiversion != null ? !apiversion.equals(that.apiversion) :that.apiversion != null) return false;
    if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiversion,  ref,  spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiversion != null) { sb.append("apiversion:"); sb.append(apiversion + ","); }
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class SpecNestedImpl<N> extends TriggerTemplateSpecFluentImpl<TriggerSpecTemplateFluent.SpecNested<N>> implements TriggerSpecTemplateFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerTemplateSpec item) {
      this.builder = new TriggerTemplateSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerTemplateSpecBuilder(this);
    }
    TriggerTemplateSpecBuilder builder;
    public N and() {
      return (N) TriggerSpecTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerSpecTemplateFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerSpecTemplateFluentImpl<A extends TriggerSpecTemplateFluent<A>> extends BaseFluent<A> implements TriggerSpecTemplateFluent<A>{
  public TriggerSpecTemplateFluentImpl() {
  }
  public TriggerSpecTemplateFluentImpl(TriggerSpecTemplate instance) {
    if (instance != null) {
      this.withApiversion(instance.getApiversion());
      this.withRef(instance.getRef());
      this.withSpec(instance.getSpec());
    }
  }
  private String apiversion;
  private String ref;
  private TriggerTemplateSpecBuilder spec;
  public String getApiversion() {
    return this.apiversion;
  }
  public A withApiversion(String apiversion) {
    this.apiversion=apiversion; return (A) this;
  }
  public Boolean hasApiversion() {
    return this.apiversion != null;
  }
  public String getRef() {
    return this.ref;
  }
  public A withRef(String ref) {
    this.ref=ref; return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerTemplateSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerTemplateSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerTemplateSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerTemplateSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerSpecTemplateFluentImpl.SpecNested<A> withNewSpec() {
    return new TriggerSpecTemplateFluentImpl.SpecNestedImpl();
  }
  public TriggerSpecTemplateFluentImpl.SpecNested<A> withNewSpecLike(TriggerTemplateSpec item) {
    return new TriggerSpecTemplateFluentImpl.SpecNestedImpl(item);
  }
  public TriggerSpecTemplateFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerSpecTemplateFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerTemplateSpecBuilder().build());
  }
  public TriggerSpecTemplateFluentImpl.SpecNested<A> editOrNewSpecLike(TriggerTemplateSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerSpecTemplateFluentImpl that = (TriggerSpecTemplateFluentImpl) o;
    if (!java.util.Objects.equals(apiversion, that.apiversion)) return false;

    if (!java.util.Objects.equals(ref, that.ref)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiversion,  ref,  spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiversion != null) { sb.append("apiversion:"); sb.append(apiversion + ","); }
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class SpecNestedImpl<N> extends TriggerTemplateSpecFluentImpl<TriggerSpecTemplateFluentImpl.SpecNested<N>> implements TriggerSpecTemplateFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerTemplateSpec item) {
      this.builder = new TriggerTemplateSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerTemplateSpecBuilder(this);
    }
    TriggerTemplateSpecBuilder builder;
    public N and() {
      return (N) TriggerSpecTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
